@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAtributes
+from RFEM.initModel import Model, clearAttributes
 
 class Instersection():
     def __init__(self,
@@ -24,7 +24,7 @@ class Instersection():
         clientObject = model.clientModel.factory.create('ns0:intersection')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Intersection No.
         clientObject.no = no
