@@ -1,4 +1,4 @@
-from RFEM.initModel import ConvertToDlString, Model, clearAtributes
+from RFEM.initModel import ConvertToDlString, Model, clearAttributes
 
 class MemberResultIntermediatePoint():
     def __init__(self,
@@ -26,7 +26,7 @@ class MemberResultIntermediatePoint():
         clientObject = model.clientModel.factory.create('ns0:member_result_intermediate_point')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Member Result Intermediate Point No.
         clientObject.no = no
