@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, ConvertToDlString, clearAtributes
+from RFEM.initModel import Model, ConvertToDlString, clearAttributes
 from RFEM.dataTypes import inf
 
 class SurfaceSupport():
@@ -33,7 +33,7 @@ class SurfaceSupport():
         clientObject = model.clientModel.factory.create('ns0:surface_support')
 
         # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
+        clearAttributes(clientObject)
 
         # Surface Support No.
         clientObject.no = no
